Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Event ¶
type Event interface{}
Event represents the minimal representation of an eventstore event
type Events ¶
type Events interface {
Len() int
Get(index int) Event
GetAll() []Event
Append(events Event)
Insert(position int, event Event)
}
Events is an abstraction for a slice of events.
type SearchQuery ¶
Click to show internal directories.
Click to hide internal directories.